==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/ro_ro/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Nu există bilete care să corespundă criteriilor de căutare.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.search.heading_summary'] = 'Rezumat';
$lang['AdminTickets.search.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.search.heading_status'] = 'Stare';
$lang['AdminTickets.search.heading_priority'] = 'Prioritate';
$lang['AdminTickets.search.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Căutați bilete pentru "%1$s"';
$lang['AdminTickets.client.no_results'] = 'În prezent nu există niciun bilet cu acest statut.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.client.heading_summary'] = 'Rezumat';
$lang['AdminTickets.client.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.client.heading_priority'] = 'Prioritate';
$lang['AdminTickets.client.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Bilete';
$lang['AdminTickets.client.categorylink_createticket'] = 'Bilet deschis';
$lang['AdminTickets.client.category_trash'] = 'Gunoi';
$lang['AdminTickets.client.category_closed'] = 'Închis';
$lang['AdminTickets.client.category_on_hold'] = 'În așteptare';
$lang['AdminTickets.client.category_in_progress'] = 'În curs de desfășurare';
$lang['AdminTickets.client.category_awaiting_reply'] = 'În așteptarea răspunsului clientului';
$lang['AdminTickets.client.category_open'] = 'În așteptarea răspunsului personalului';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Ștergeți fișierul';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';
$lang['AdminTickets.reply.staff_title'] = 'Personal de sprijin';
$lang['AdminTickets.reply.system'] = 'Sistem';
$lang['AdminTickets.reply.log_date'] = '%1$s de %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'La %1$s %2$s %2$s %3$s a răspuns';
$lang['AdminTickets.reply.refresh_link'] = 'Faceți clic pentru a afișa.';
$lang['AdminTickets.reply.refresh'] = 'Există răspunsuri noi sau modificări de stare.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Du-te';
$lang['AdminTickets.reply.field_replysubmit'] = 'Actualizare bilet';
$lang['AdminTickets.reply.text_add_attachment'] = 'Adăugați atașament';
$lang['AdminTickets.reply.field_attachments'] = 'Atașamente';
$lang['AdminTickets.reply.field_note'] = 'Notă';
$lang['AdminTickets.reply.field_reply'] = 'Răspuns';
$lang['AdminTickets.reply.heading_reply'] = 'Adaugă răspuns';
$lang['AdminTickets.reply.text_with_selected'] = 'Cu răspunsurile selectate, efectuați:';
$lang['AdminTickets.reply.text_add_response'] = 'Introduceți un răspuns predefinit';
$lang['AdminTickets.reply.heading_date_added'] = 'Data deschiderii';
$lang['AdminTickets.reply.heading_status'] = 'Stare';
$lang['AdminTickets.reply.heading_priority'] = 'Prioritate';
$lang['AdminTickets.reply.heading_staff_id'] = 'Atribuit la';
$lang['AdminTickets.reply.heading_department'] = 'Departamentul';
$lang['AdminTickets.reply.heading_client'] = 'Client';
$lang['AdminTickets.reply.heading_summary'] = 'Rezumat';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Ștergeți fișierul';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';
$lang['AdminTickets.add.text_add_response'] = 'Introduceți un răspuns predefinit';
$lang['Admintickets.add.client_placeholder'] = 'ID-ul sau numele clientului';
$lang['AdminTickets.add.field_addsubmit'] = 'Bilet deschis';
$lang['AdminTickets.add.text_add_attachment'] = 'Adăugați atașament';
$lang['AdminTickets.add.field_details'] = 'Detalii';
$lang['AdminTickets.add.field_attachments'] = 'Atașamente';
$lang['AdminTickets.add.heading_status'] = 'Stare';
$lang['AdminTickets.add.heading_priority'] = 'Prioritate';
$lang['AdminTickets.add.heading_staff_id'] = 'Atribuit la';
$lang['AdminTickets.add.heading_department'] = 'Departamentul';
$lang['AdminTickets.add.heading_client'] = 'Client';
$lang['AdminTickets.add.heading_summary'] = 'Rezumat';
$lang['AdminTickets.add.text_no_clients'] = 'Nu s-au găsit clienți. Încercați să căutați din nou.';
$lang['AdminTickets.add.heading_search_client'] = 'Căutarea clientului';
$lang['AdminTickets.add.boxtitle_add'] = 'Bilet deschis';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Trimiteți';
$lang['AdminTickets.index.text_no_tickets'] = 'Nu s-au găsit bilete deschise. Încercați să căutați din nou.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Număr de bilet';
$lang['AdminTickets.index.text_to_status'] = 'Se schimbă în:';
$lang['AdminTickets.index.text_to_client'] = 'Către client:';
$lang['AdminTickets.index.text_into_ticket'] = 'În bilet:';
$lang['AdminTickets.index.text_with_selected'] = 'Cu bilete selecționate, efectuați:';
$lang['AdminTickets.index.no_results'] = 'În prezent nu există niciun bilet cu acest statut.';
$lang['AdminTickets.index.last_reply_by'] = 'de';
$lang['AdminTickets.index.unassigned'] = 'Neatribuite';
$lang['AdminTickets.index.field_last_reply'] = 'Ultimul răspuns';
$lang['AdminTickets.index.field_assigned_staff'] = 'Atribuit la';
$lang['AdminTickets.index.field_summary'] = 'Rezumat';
$lang['AdminTickets.index.field_department_id'] = 'Departamentul';
$lang['AdminTickets.index.field_priority'] = 'Prioritate';
$lang['AdminTickets.index.field_ticket_number'] = 'Număr de bilet';
$lang['AdminTickets.index.hours'] = '%1$s ore';
$lang['AdminTickets.index.hour'] = '1 oră';
$lang['AdminTickets.index.minutes'] = '%1$s minute';
$lang['AdminTickets.index.any'] = 'Orice';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Atribuit la';
$lang['AdminTickets.index.heading_summary'] = 'Rezumat';
$lang['AdminTickets.index.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.index.heading_priority'] = 'Prioritate';
$lang['AdminTickets.index.heading_client'] = 'Client';
$lang['AdminTickets.index.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Bilete';
$lang['AdminTickets.index.categorylink_createticket'] = 'Bilet deschis';
$lang['AdminTickets.index.category_trash'] = 'Gunoi';
$lang['AdminTickets.index.category_closed'] = 'Închis';
$lang['AdminTickets.index.category_on_hold'] = 'În așteptare';
$lang['AdminTickets.index.category_in_progress'] = 'În curs de desfășurare';
$lang['AdminTickets.index.category_awaiting_reply'] = 'În așteptarea răspunsului clientului';
$lang['AdminTickets.index.category_open'] = 'În așteptarea răspunsului personalului';
$lang['AdminTickets.text.unassigned'] = 'Neatribuit';
$lang['AdminTickets.search.page_title'] = 'Rezultate căutare pentru "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Manager de asistență > Bilet #%1$s';
$lang['AdminTickets.add.page_title'] = 'Manager de asistență > Deschideți un bilet';
$lang['AdminTickets.index.page_title'] = 'Manager de suport > Bilete';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Încă nu au fost create personal și/sau departamente. Faceți clic pe %1$s de mai sus pentru a crea un departament sau pe %2$s pentru a atribui un membru al personalului.';
$lang['AdminTickets.!success.ticket_delete'] = 'Biletele selectate au fost șterse cu succes.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Biletele selectate au fost actualizate cu succes.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Biletele selectate au fost realocate cu succes.';
$lang['AdminTickets.!success.ticket_merge'] = 'Biletele selectate au fost fuzionate cu succes în biletul #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Biletul #%1$s a fost împărțit cu succes în biletul #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Biletul #%1$s a fost actualizat cu succes.';
$lang['AdminTickets.!success.ticket_created'] = 'Biletul #%1$s a fost deschis cu succes.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/ro_ro/admin_tickets.php <==
<?php
/**
 * Admin Tickets
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminTickets.search.no_results'] = 'Nu există bilete care să corespundă criteriilor de căutare.';
$lang['AdminTickets.search.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.search.heading_summary'] = 'Rezumat';
$lang['AdminTickets.search.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.search.heading_status'] = 'Stare';
$lang['AdminTickets.search.heading_priority'] = 'Prioritate';
$lang['AdminTickets.search.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.search.boxtitle_tickets'] = 'Căutați bilete pentru "%1$s"';
$lang['AdminTickets.client.no_results'] = 'În prezent nu există niciun bilet cu acest statut.';
$lang['AdminTickets.client.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.client.heading_summary'] = 'Rezumat';
$lang['AdminTickets.client.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.client.heading_priority'] = 'Prioritate';
$lang['AdminTickets.client.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.client.boxtitle_tickets'] = 'Bilete';
$lang['AdminTickets.client.categorylink_createticket'] = 'Bilet deschis';
$lang['AdminTickets.client.category_trash'] = 'Gunoi';
$lang['AdminTickets.client.category_closed'] = 'Închis';
$lang['AdminTickets.client.category_on_hold'] = 'În așteptare';
$lang['AdminTickets.client.category_in_progress'] = 'În curs de desfășurare';
$lang['AdminTickets.client.category_awaiting_reply'] = 'În așteptarea răspunsului clientului';
$lang['AdminTickets.client.category_open'] = 'În așteptarea răspunsului personalului';
$lang['AdminTickets.reply.dropzone_remove_file'] = 'Ștergeți fișierul';
$lang['AdminTickets.reply.dropzone_drop_files_here'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';
$lang['AdminTickets.reply.staff_title'] = 'Personal de sprijin';
$lang['AdminTickets.reply.system'] = 'Sistem';
$lang['AdminTickets.reply.log_date'] = '%1$s de %2$s %3$s';
$lang['AdminTickets.reply.reply_date'] = 'La %1$s %2$s %2$s %3$s a răspuns';
$lang['AdminTickets.reply.refresh_link'] = 'Faceți clic pentru a afișa.';
$lang['AdminTickets.reply.refresh'] = 'Există răspunsuri noi sau modificări de stare.';
$lang['AdminTickets.reply.field_actionsubmit'] = 'Du-te';
$lang['AdminTickets.reply.field_replysubmit'] = 'Actualizare bilet';
$lang['AdminTickets.reply.text_add_attachment'] = 'Adăugați atașament';
$lang['AdminTickets.reply.field_attachments'] = 'Atașamente';
$lang['AdminTickets.reply.field_note'] = 'Notă';
$lang['AdminTickets.reply.field_reply'] = 'Răspuns';
$lang['AdminTickets.reply.heading_reply'] = 'Adaugă răspuns';
$lang['AdminTickets.reply.text_with_selected'] = 'Cu răspunsurile selectate, efectuați:';
$lang['AdminTickets.reply.text_add_response'] = 'Introduceți un răspuns predefinit';
$lang['AdminTickets.reply.heading_date_added'] = 'Data deschiderii';
$lang['AdminTickets.reply.heading_status'] = 'Stare';
$lang['AdminTickets.reply.heading_priority'] = 'Prioritate';
$lang['AdminTickets.reply.heading_staff_id'] = 'Atribuit la';
$lang['AdminTickets.reply.heading_department'] = 'Departamentul';
$lang['AdminTickets.reply.heading_client'] = 'Client';
$lang['AdminTickets.reply.heading_summary'] = 'Rezumat';
$lang['AdminTickets.reply.boxtitle_reply'] = 'Bilet #%1$s';
$lang['AdminTickets.add.dropzone_remove_file'] = 'Ștergeți fișierul';
$lang['AdminTickets.add.dropzone_drop_files_here'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';
$lang['AdminTickets.add.text_add_response'] = 'Introduceți un răspuns predefinit';
$lang['Admintickets.add.client_placeholder'] = 'ID-ul sau numele clientului';
$lang['AdminTickets.add.field_addsubmit'] = 'Bilet deschis';
$lang['AdminTickets.add.text_add_attachment'] = 'Adăugați atașament';
$lang['AdminTickets.add.field_details'] = 'Detalii';
$lang['AdminTickets.add.field_attachments'] = 'Atașamente';
$lang['AdminTickets.add.heading_status'] = 'Stare';
$lang['AdminTickets.add.heading_priority'] = 'Prioritate';
$lang['AdminTickets.add.heading_staff_id'] = 'Atribuit la';
$lang['AdminTickets.add.heading_department'] = 'Departamentul';
$lang['AdminTickets.add.heading_client'] = 'Client';
$lang['AdminTickets.add.heading_summary'] = 'Rezumat';
$lang['AdminTickets.add.text_no_clients'] = 'Nu s-au găsit clienți. Încercați să căutați din nou.';
$lang['AdminTickets.add.heading_search_client'] = 'Căutarea clientului';
$lang['AdminTickets.add.boxtitle_add'] = 'Bilet deschis';
$lang['AdminTickets.index.ticket_email'] = '#%1$s %2$s';
$lang['AdminTickets.index.ticket_name'] = '#%1$s %2$s %3$s';
$lang['AdminTickets.index.field_actionsubmit'] = 'Trimiteți';
$lang['AdminTickets.index.text_no_tickets'] = 'Nu s-au găsit bilete deschise. Încercați să căutați din nou.';
$lang['AdminTickets.index.ticket_number_placeholder'] = 'Număr de bilet';
$lang['AdminTickets.index.text_to_status'] = 'Se schimbă în:';
$lang['AdminTickets.index.text_to_client'] = 'Către client:';
$lang['AdminTickets.index.text_into_ticket'] = 'În bilet:';
$lang['AdminTickets.index.text_with_selected'] = 'Cu bilete selecționate, efectuați:';
$lang['AdminTickets.index.no_results'] = 'În prezent nu există niciun bilet cu acest statut.';
$lang['AdminTickets.index.last_reply_by'] = 'de';
$lang['AdminTickets.index.unassigned'] = 'Neatribuite';
$lang['AdminTickets.index.field_last_reply'] = 'Ultimul răspuns';
$lang['AdminTickets.index.field_assigned_staff'] = 'Atribuit la';
$lang['AdminTickets.index.field_summary'] = 'Rezumat';
$lang['AdminTickets.index.field_department_id'] = 'Departamentul';
$lang['AdminTickets.index.field_priority'] = 'Prioritate';
$lang['AdminTickets.index.field_ticket_number'] = 'Număr de bilet';
$lang['AdminTickets.index.hours'] = '%1$s ore';
$lang['AdminTickets.index.hour'] = '1 oră';
$lang['AdminTickets.index.minutes'] = '%1$s minute';
$lang['AdminTickets.index.any'] = 'Orice';
$lang['AdminTickets.index.heading_last_reply_date'] = 'Ultimul răspuns';
$lang['AdminTickets.index.heading_assigned_staff'] = 'Atribuit la';
$lang['AdminTickets.index.heading_summary'] = 'Rezumat';
$lang['AdminTickets.index.heading_department_name'] = 'Departamentul';
$lang['AdminTickets.index.heading_priority'] = 'Prioritate';
$lang['AdminTickets.index.heading_client'] = 'Client';
$lang['AdminTickets.index.heading_code'] = 'Număr de bilet';
$lang['AdminTickets.index.boxtitle_tickets'] = 'Bilete';
$lang['AdminTickets.index.categorylink_createticket'] = 'Bilet deschis';
$lang['AdminTickets.index.category_trash'] = 'Gunoi';
$lang['AdminTickets.index.category_closed'] = 'Închis';
$lang['AdminTickets.index.category_on_hold'] = 'În așteptare';
$lang['AdminTickets.index.category_in_progress'] = 'În curs de desfășurare';
$lang['AdminTickets.index.category_awaiting_reply'] = 'În așteptarea răspunsului clientului';
$lang['AdminTickets.index.category_open'] = 'În așteptarea răspunsului personalului';
$lang['AdminTickets.text.unassigned'] = 'Neatribuit';
$lang['AdminTickets.search.page_title'] = 'Rezultate căutare pentru "%1$s"';
$lang['AdminTickets.reply.page_title'] = 'Manager de asistență > Bilet #%1$s';
$lang['AdminTickets.add.page_title'] = 'Manager de asistență > Deschideți un bilet';
$lang['AdminTickets.index.page_title'] = 'Manager de suport > Bilete';
$lang['AdminTickets.!notice.no_departments_staff'] = 'Încă nu au fost create personal și/sau departamente. Faceți clic pe %1$s de mai sus pentru a crea un departament sau pe %2$s pentru a atribui un membru al personalului.';
$lang['AdminTickets.!success.ticket_delete'] = 'Biletele selectate au fost șterse cu succes.';
$lang['AdminTickets.!success.ticket_update_status'] = 'Biletele selectate au fost actualizate cu succes.';
$lang['AdminTickets.!success.ticket_reassign'] = 'Biletele selectate au fost realocate cu succes.';
$lang['AdminTickets.!success.ticket_merge'] = 'Biletele selectate au fost fuzionate cu succes în biletul #%1$s.';
$lang['AdminTickets.!success.ticket_split'] = 'Biletul #%1$s a fost împărțit cu succes în biletul #%2$s.';
$lang['AdminTickets.!success.ticket_updated'] = 'Biletul #%1$s a fost actualizat cu succes.';
$lang['AdminTickets.!success.ticket_created'] = 'Biletul #%1$s a fost deschis cu succes.';
$lang['AdminTickets.reply.text_contacts'] = 'Contactele care nu sunt selectate vor fi adăugate automat la bilet dacă răspund la acesta.';
$lang['AdminTickets.reply.text_add_recipient'] = 'Adăugați destinatar';
$lang['AdminTickets.reply.heading_contacts'] = 'Contacte';
$lang['AdminTickets.reply.heading_recipients'] = 'Beneficiari';
$lang['AdminTickets.add.text_contacts'] = 'Contactele care nu sunt selectate vor fi adăugate automat la bilet dacă răspund la acesta.';
$lang['AdminTickets.add.text_add_recipient'] = 'Adăugați destinatar';
$lang['AdminTickets.add.heading_contacts'] = 'Contacte';
$lang['AdminTickets.add.heading_recipients'] = 'Beneficiari';
